@@ -7,18 +7,10 @@ from .base_core import _BaseCore
 
 
 class _MemoryCore(_BaseCore):
-    """The pickle core class for cachier.
+    """The memory core class for cachier."""
 
-    Parameters
-    ----------
-    stale_after : datetime.timedelta, optional
-        See :class:`_BaseCore` documentation.
-    next_time : bool, optional
-        See :class:`_BaseCore` documentation.
-    """
-
-    def __init__(self, hash_func):
-        super().__init__(hash_func)
+    def __init__(self, hash_func, default_params):
+        super().__init__(hash_func, default_params)
         self.cache = {}
         self.lock = threading.RLock()
 
@@ -74,10 +66,10 @@ class _MemoryCore(_BaseCore):
                 entry['condition'] = None
 
     def wait_on_entry_calc(self, key):
-        with self.lock:
+        with self.lock:  # pragma: no cover
             entry = self.cache[key]
             if not entry['being_calculated']:
-                return entry['value']  # pragma: no cover
+                return entry['value']
         entry['condition'].acquire()
         entry['condition'].wait()
         entry['condition'].release()
