@@ -32,7 +32,7 @@ import hashlib
 import pandas as pd
 
 from cachier import cachier
-from cachier.pickle_core import DEF_CACHIER_DIR
+from cachier.core import _default_params
 
 
 def _get_decorated_func(func, **kwargs):
@@ -49,11 +49,14 @@ def _takes_2_seconds(arg_1, arg_2):
     return 'arg_1:{}, arg_2:{}'.format(arg_1, arg_2)
 
 
+@pytest.mark.pickle
+@pytest.mark.parametrize('reload', [True, False])
 @pytest.mark.parametrize('separate_files', [True, False])
-def test_pickle_core(separate_files):
+def test_pickle_core(reload, separate_files):
     """Basic Pickle core functionality."""
     _takes_2_seconds_decorated = _get_decorated_func(
-        _takes_2_seconds, next_time=False, separate_files=separate_files)
+        _takes_2_seconds, next_time=False,
+        pickle_reload=reload, separate_files=separate_files)
     _takes_2_seconds_decorated.clear_cache()
     _takes_2_seconds_decorated('a', 'b')
     start = time()
@@ -63,6 +66,7 @@ def test_pickle_core(separate_files):
     _takes_2_seconds_decorated.clear_cache()
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_pickle_core_keywords(separate_files):
     """Basic Pickle core functionality with keyword arguments."""
@@ -86,6 +90,7 @@ def _stale_after_seconds(arg_1, arg_2):
     return random()
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_stale_after(separate_files):
     """Testing the stale_after functionality."""
@@ -110,6 +115,7 @@ def _stale_after_next_time(arg_1, arg_2):
     return random()
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_stale_after_next_time(separate_files):
     """Testing the stale_after with next_time functionality."""
@@ -141,6 +147,7 @@ def _random_num_with_arg(a):
     return random()
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_overwrite_cache(separate_files):
     """Tests that the overwrite feature works correctly."""
@@ -169,6 +176,7 @@ def test_overwrite_cache(separate_files):
     _random_num_with_arg_decorated.clear_cache()
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_ignore_cache(separate_files):
     """Tests that the ignore_cache feature works correctly."""
@@ -210,6 +218,7 @@ def _calls_takes_time(takes_time_func, res_queue):
     res_queue.put(res)
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_pickle_being_calculated(separate_files):
     """Testing pickle core handling of being calculated scenarios."""
@@ -236,8 +245,8 @@ def test_pickle_being_calculated(separate_files):
     thread1.start()
     sleep(0.5)
     thread2.start()
-    thread1.join(timeout=3)
-    thread2.join(timeout=3)
+    thread1.join(timeout=4)
+    thread2.join(timeout=4)
     assert res_queue.qsize() == 2
     res1 = res_queue.get()
     res2 = res_queue.get()
@@ -255,6 +264,7 @@ def _calls_being_calc_next_time(being_calc_func, res_queue):
     res_queue.put(res)
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_being_calc_next_time(separate_files):
     """Testing pickle core handling of being calculated scenarios."""
@@ -307,7 +317,7 @@ _BAD_CACHE_FNAME_SEPARATE_FILES = (
     '.tests.test_pickle_core._bad_cache_'
     f'{hashlib.sha256(pickle.dumps((0.13, 0.02))).hexdigest()}'
 )
-EXPANDED_CACHIER_DIR = os.path.expanduser(DEF_CACHIER_DIR)
+EXPANDED_CACHIER_DIR = os.path.expanduser(_default_params['cache_dir'])
 _BAD_CACHE_FPATH = os.path.join(EXPANDED_CACHIER_DIR, _BAD_CACHE_FNAME)
 _BAD_CACHE_FPATH_SEPARATE_FILES = os.path.join(
     EXPANDED_CACHIER_DIR, _BAD_CACHE_FNAME_SEPARATE_FILES)
@@ -372,6 +382,7 @@ def _helper_bad_cache_file(sleeptime, separate_files):
 
 
 # we want this to succeed at leat once
+@pytest.mark.pickle
 @pytest.mark.xfail
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_bad_cache_file(separate_files):
@@ -464,6 +475,7 @@ def _helper_delete_cache_file(sleeptime, separate_files):
     # print(type(res2))
 
 
+@pytest.mark.pickle
 @pytest.mark.xfail
 @pytest.mark.parametrize('separate_files', [False, True])
 def test_delete_cache_file(separate_files):
@@ -476,6 +488,7 @@ def test_delete_cache_file(separate_files):
     assert False
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [False, True])
 def test_clear_being_calculated(separate_files):
     """Test pickle core clear `being calculated` functionality."""
@@ -493,6 +506,7 @@ def _error_throwing_func(arg1):
     return 7
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_error_throwing_func(separate_files):
     # with
@@ -522,6 +536,7 @@ def _takes_2_seconds_custom_dir(arg_1, arg_2):
     return 'arg_1:{}, arg_2:{}'.format(arg_1, arg_2)
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_pickle_core_custom_cache_dir(separate_files):
     """Basic Pickle core functionality."""
@@ -540,6 +555,7 @@ def test_pickle_core_custom_cache_dir(separate_files):
     assert path2test == EXPANDED_CUSTOM_DIR
 
 
+@pytest.mark.pickle
 @pytest.mark.parametrize('separate_files', [True, False])
 def test_callable_hash_param(separate_files):
     def _hash_func(args, kwargs):
